{% load static %}
<!-- TOPBAR -->
<div id="topbar" style="background: {{COLORS.topbar}}; position: fixed; top: 0px; left: 0px; right: 0px; height: 50px; box-shadow: 0 0 10px #00000050; z-index: 10; "> <!-- box-shadow: 0px 0px 3px #55555550; -->
	<div id="topbar.left" style="display: flex; padding-right: 10px; left: 0px; position: absolute; ">
		<img src="{% static 'favicon.png' %}" alt="vandenberghinc" width="20" style="margin-top: 14px; margin-left: 25px; height: 20px; width: 20px;" />
		<h1 class="title" style="font-size: 14px; margin-top: 15px; margin-left: 25px; color: {{COLORS.white}}; font-weight: 500;">
			{{NAME}}
		</h1>
		<h1 id="header_path" class="title" style="font-size: 11px; margin-top: 18px; margin-left: 5px; color: {{COLORS.white}}; font-weight: 300;">
			- dashboard/
		</h1>
	</div>
	<div id="topbar.right" style="display: flex; padding-right: 10px; right: 0px; position: absolute; padding-right: 25px;">
		<a id="topbar.filters" onclick="__toggle_filters__()" href="#" class="empty_a" style="margin-left: 15px; display: none;">
			<img onclick="" src="{% static 'media/icons/white/filter_1.png' %}" alt="VanDenBerghInc" width="17.5px" height="17.5px" style="margin-top: 15px;" />
		</a>
		<a id="topbar.packages" href="/packages/packages/" class="empty_a" style="margin-left: 15px;">
			<img onclick="" src="{% static 'media/icons/white/search_2.png' %}" alt="VanDenBerghInc" width="17.5px" height="17.5px" style="margin-top: 15px;" />
		</a>
		<a id="topbar.account" href="/accounts/account/" class="empty_a" style="margin-left: 15px;">
			<img onclick="" src="{% static 'media/icons/white/user_7.png' %}" alt="VanDenBerghInc" width="17.5px" height="17.5px" style="margin-top: 15px;" />
		</a> 
		<a id="topbar.signout" href="#" class="empty_a" style="margin-left: 15px;">
			<img onclick="signout()" src="{% static 'media/icons/white/exit.png' %}" alt="VanDenBerghInc" width="17.5px" height="17.5px" style="margin-top: 15px;" />
		</a> 
	</div>
</div> 		
<script type="text/javascript">
	function signout() {
		request("/requests/accounts/signout/", {}, function(response) {
			location.href = "/"
		})
	}
</script>